# SciBatt
Reading, filtering and plotting electrochemical data

The package is built out of three submodules: 
- **Readers** which transform raw data into a standardized format
- **Filters** which allows transformations, calculations and changes to the data
- **Plotters** which allows easy plotting of the data from Readers or Filters.

The package is intended to be used to import into your own script